summaryrefslogtreecommitdiffstats
path: root/o3d/tests/selenium/samples_tests.py
diff options
context:
space:
mode:
Diffstat (limited to 'o3d/tests/selenium/samples_tests.py')
-rw-r--r--o3d/tests/selenium/samples_tests.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/o3d/tests/selenium/samples_tests.py b/o3d/tests/selenium/samples_tests.py
index 0a83eb5..06c52fb 100644
--- a/o3d/tests/selenium/samples_tests.py
+++ b/o3d/tests/selenium/samples_tests.py
@@ -180,8 +180,9 @@ class SampleTests(selenium_utilities.SeleniumTestCase):
self.assertEqual("null", s.get_eval("window.undefined_symbol_xxxyyy"))
# Try different views of the camera
- # Set delay between each operation at 100ms.
- s.set_speed(100)
+ # Set delay between each operation at 10ms.
+ speed = int(s.get_speed())
+ s.set_speed(10)
s.type("eyeX", "5")
s.type("eyeY", "5")
s.type("eyeZ", "5")
@@ -193,8 +194,8 @@ class SampleTests(selenium_utilities.SeleniumTestCase):
s.type("upX", "1")
s.type("upY", "0")
s.click("btnSet")
- # Reset delay to default value, 0ms.
- s.set_speed(0)
+ # Reset delay to previous value.
+ s.set_speed(speed)
# Capture screenshot
self.assertTrue(selenium_utilities.TakeScreenShot(s, self.browser,